============
Census Areas
============

This Python library extends the Sunlight Foundation's `Census API Wrapper <https://github.com/sunlightlabs/census/>`_ to allow querying Census tracts, block groups, and blocks by Census place, as well as by  arbitrary geographies.

Setup
=====

Get the library and its dependencies using `pip <https://pypi.python.org/pypi/pip>`_:

::

    pip install census_area

Usage
=====

`Check out the documentation on Read The Docs <https://census-area.readthedocs.io/en/latest/>`_.

Team
====

* Jean Cochrane, DataMade
* Forest Gregg, DataMade
* Hannah Cushman Garland, DataMade

Errors and bugs
===============

If something is not behaving intuitively, it is a bug and should be reported.
Report it here by creating an issue: https://github.com/datamade/census_area/issues

Help us fix the problem as quickly as possible by following `Mozilla's guidelines for reporting bugs. <https://developer.mozilla.org/en-US/docs/Mozilla/QA/Bug_writing_guidelines#General_Outline_of_a_Bug_Report>`_

Patches and pull requests
=========================

Your patches are welcome. Here's our suggested workflow:

* Fork the project.
* Make your feature addition or bug fix.
* Send us a pull request with a description of your work. Bonus points for topic branches!

Copyright and attribution
=========================

Copyright (c) 2022 DataMade. Released under the `MIT License <https://github.com/datamade/census_area/blob/master/LICENSE.md>`_.
